package admin_role

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"
	"qnc-server/app/main/api/internal/logic/admin_role"
	"qnc-server/app/main/api/internal/svc"
	"qnc-server/app/main/api/internal/types"
	"qnc-server/common/result"
	"qnc-server/pkg/lzkit/validator"
)

func CreateRoleHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.CreateRoleReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := admin_role.NewCreateRoleLogic(r.Context(), svcCtx)
		resp, err := l.CreateRole(&req)
		result.HttpResult(r, w, resp, err)
	}
}
