package auth

import (
	"net/http"

	"qnc-server/app/main/api/internal/logic/auth"
	"qnc-server/app/main/api/internal/svc"
	"qnc-server/app/main/api/internal/types"
	"qnc-server/common/result"
	"qnc-server/pkg/lzkit/validator"

	"github.com/zeromicro/go-zero/rest/httpx"
)

func SmsAuthorizationHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.SmsAuthorizationReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := auth.NewSmsAuthorizationLogic(r.Context(), svcCtx)
		resp, err := l.SmsAuthorization(&req)
		result.HttpResult(r, w, resp, err)
	}
}
