package query

import (
	"net/http"

	"qnc-server/app/main/api/internal/logic/query"
	"qnc-server/app/main/api/internal/svc"
	"qnc-server/app/main/api/internal/types"
	"qnc-server/common/result"
	"qnc-server/pkg/lzkit/validator"

	"github.com/zeromicro/go-zero/rest/httpx"
)

func QueryRetryHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.QueryRetryReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := query.NewQueryRetryLogic(r.Context(), svcCtx)
		resp, err := l.QueryRetry(&req)
		result.HttpResult(r, w, resp, err)
	}
}
