// Code generated by goctl. DO NOT EDIT!

package model

import (
	"context"
	"database/sql"
	"fmt"
	"strings"

	"time"

	"github.com/Masterminds/squirrel"
	"github.com/pkg/errors"
	"github.com/zeromicro/go-zero/core/stores/builder"
	"github.com/zeromicro/go-zero/core/stores/cache"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
	"github.com/zeromicro/go-zero/core/stringx"
	"qnc-server/common/globalkey"
)

var (
	authorizationFieldNames          = builder.RawFieldNames(&Authorization{})
	authorizationRows                = strings.Join(authorizationFieldNames, ",")
	authorizationRowsExpectAutoSet   = strings.Join(stringx.Remove(authorizationFieldNames, "`id`", "`create_time`", "`update_time`"), ",")
	authorizationRowsWithPlaceHolder = strings.Join(stringx.Remove(authorizationFieldNames, "`id`", "`create_time`", "`update_time`"), "=?,") + "=?"

	cacheQncAuthorizationIdPrefix      = "cache:qnc:authorization:id:"
	cacheQncAuthorizationOrderIdPrefix = "cache:qnc:authorization:orderId:"
)

type (
	authorizationModel interface {
		Insert(ctx context.Context, session sqlx.Session, data *Authorization) (sql.Result, error)
		FindOne(ctx context.Context, id int64) (*Authorization, error)
		FindOneByOrderId(ctx context.Context, orderId int64) (*Authorization, error)
		Update(ctx context.Context, session sqlx.Session, data *Authorization) (sql.Result, error)
		UpdateWithVersion(ctx context.Context, session sqlx.Session, data *Authorization) error
		Trans(ctx context.Context, fn func(context context.Context, session sqlx.Session) error) error
		SelectBuilder() squirrel.SelectBuilder
		DeleteSoft(ctx context.Context, session sqlx.Session, data *Authorization) error
		FindSum(ctx context.Context, sumBuilder squirrel.SelectBuilder, field string) (float64, error)
		FindCount(ctx context.Context, countBuilder squirrel.SelectBuilder, field string) (int64, error)
		FindAll(ctx context.Context, rowBuilder squirrel.SelectBuilder, orderBy string) ([]*Authorization, error)
		FindPageListByPage(ctx context.Context, rowBuilder squirrel.SelectBuilder, page, pageSize int64, orderBy string) ([]*Authorization, error)
		FindPageListByPageWithTotal(ctx context.Context, rowBuilder squirrel.SelectBuilder, page, pageSize int64, orderBy string) ([]*Authorization, int64, error)
		FindPageListByIdDESC(ctx context.Context, rowBuilder squirrel.SelectBuilder, preMinId, pageSize int64) ([]*Authorization, error)
		FindPageListByIdASC(ctx context.Context, rowBuilder squirrel.SelectBuilder, preMaxId, pageSize int64) ([]*Authorization, error)
		Delete(ctx context.Context, session sqlx.Session, id int64) error
	}

	defaultAuthorizationModel struct {
		sqlc.CachedConn
		table string
	}

	Authorization struct {
		Id           int64          `db:"id"`
		OrderId      int64          `db:"order_id"`
		GrantType    sql.NullString `db:"grant_type"`
		AuthType     sql.NullInt64  `db:"auth_type"` // 1本人，2他人
		UserId       int64          `db:"user_id"`
		TargetName   string         `db:"target_name"`
		TargetIdcard string         `db:"target_idcard"`
		Status       string         `db:"status"` // 授权状态：pending待授权、success已授权、expired已失效、revoked已撤销、rejected被拒绝
		CreateTime   time.Time      `db:"create_time"`
		UpdateTime   time.Time      `db:"update_time"`
		DeleteTime   sql.NullTime   `db:"delete_time"` // 删除时间
		DelState     int64          `db:"del_state"`
		Version      int64          `db:"version"` // 版本号
	}
)

func newAuthorizationModel(conn sqlx.SqlConn, c cache.CacheConf) *defaultAuthorizationModel {
	return &defaultAuthorizationModel{
		CachedConn: sqlc.NewConn(conn, c),
		table:      "`authorization`",
	}
}

func (m *defaultAuthorizationModel) Insert(ctx context.Context, session sqlx.Session, data *Authorization) (sql.Result, error) {
	data.DelState = globalkey.DelStateNo
	qncAuthorizationIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, data.Id)
	qncAuthorizationOrderIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationOrderIdPrefix, data.OrderId)
	return m.ExecCtx(ctx, func(ctx context.Context, conn sqlx.SqlConn) (result sql.Result, err error) {
		query := fmt.Sprintf("insert into %s (%s) values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", m.table, authorizationRowsExpectAutoSet)
		if session != nil {
			return session.ExecCtx(ctx, query, data.OrderId, data.GrantType, data.AuthType, data.UserId, data.TargetName, data.TargetIdcard, data.Status, data.DeleteTime, data.DelState, data.Version)
		}
		return conn.ExecCtx(ctx, query, data.OrderId, data.GrantType, data.AuthType, data.UserId, data.TargetName, data.TargetIdcard, data.Status, data.DeleteTime, data.DelState, data.Version)
	}, qncAuthorizationIdKey, qncAuthorizationOrderIdKey)
}

func (m *defaultAuthorizationModel) FindOne(ctx context.Context, id int64) (*Authorization, error) {
	qncAuthorizationIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, id)
	var resp Authorization
	err := m.QueryRowCtx(ctx, &resp, qncAuthorizationIdKey, func(ctx context.Context, conn sqlx.SqlConn, v interface{}) error {
		query := fmt.Sprintf("select %s from %s where `id` = ? and del_state = ? limit 1", authorizationRows, m.table)
		return conn.QueryRowCtx(ctx, v, query, id, globalkey.DelStateNo)
	})
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) FindOneByOrderId(ctx context.Context, orderId int64) (*Authorization, error) {
	qncAuthorizationOrderIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationOrderIdPrefix, orderId)
	var resp Authorization
	err := m.QueryRowIndexCtx(ctx, &resp, qncAuthorizationOrderIdKey, m.formatPrimary, func(ctx context.Context, conn sqlx.SqlConn, v interface{}) (i interface{}, e error) {
		query := fmt.Sprintf("select %s from %s where `order_id` = ? and del_state = ? limit 1", authorizationRows, m.table)
		if err := conn.QueryRowCtx(ctx, &resp, query, orderId, globalkey.DelStateNo); err != nil {
			return nil, err
		}
		return resp.Id, nil
	}, m.queryPrimary)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) Update(ctx context.Context, session sqlx.Session, newData *Authorization) (sql.Result, error) {
	data, err := m.FindOne(ctx, newData.Id)
	if err != nil {
		return nil, err
	}
	qncAuthorizationIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, data.Id)
	qncAuthorizationOrderIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationOrderIdPrefix, data.OrderId)
	return m.ExecCtx(ctx, func(ctx context.Context, conn sqlx.SqlConn) (result sql.Result, err error) {
		query := fmt.Sprintf("update %s set %s where `id` = ?", m.table, authorizationRowsWithPlaceHolder)
		if session != nil {
			return session.ExecCtx(ctx, query, newData.OrderId, newData.GrantType, newData.AuthType, newData.UserId, newData.TargetName, newData.TargetIdcard, newData.Status, newData.DeleteTime, newData.DelState, newData.Version, newData.Id)
		}
		return conn.ExecCtx(ctx, query, newData.OrderId, newData.GrantType, newData.AuthType, newData.UserId, newData.TargetName, newData.TargetIdcard, newData.Status, newData.DeleteTime, newData.DelState, newData.Version, newData.Id)
	}, qncAuthorizationIdKey, qncAuthorizationOrderIdKey)
}

func (m *defaultAuthorizationModel) UpdateWithVersion(ctx context.Context, session sqlx.Session, newData *Authorization) error {

	oldVersion := newData.Version
	newData.Version += 1

	var sqlResult sql.Result
	var err error

	data, err := m.FindOne(ctx, newData.Id)
	if err != nil {
		return err
	}
	qncAuthorizationIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, data.Id)
	qncAuthorizationOrderIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationOrderIdPrefix, data.OrderId)
	sqlResult, err = m.ExecCtx(ctx, func(ctx context.Context, conn sqlx.SqlConn) (result sql.Result, err error) {
		query := fmt.Sprintf("update %s set %s where `id` = ? and version = ? ", m.table, authorizationRowsWithPlaceHolder)
		if session != nil {
			return session.ExecCtx(ctx, query, newData.OrderId, newData.GrantType, newData.AuthType, newData.UserId, newData.TargetName, newData.TargetIdcard, newData.Status, newData.DeleteTime, newData.DelState, newData.Version, newData.Id, oldVersion)
		}
		return conn.ExecCtx(ctx, query, newData.OrderId, newData.GrantType, newData.AuthType, newData.UserId, newData.TargetName, newData.TargetIdcard, newData.Status, newData.DeleteTime, newData.DelState, newData.Version, newData.Id, oldVersion)
	}, qncAuthorizationIdKey, qncAuthorizationOrderIdKey)
	if err != nil {
		return err
	}
	updateCount, err := sqlResult.RowsAffected()
	if err != nil {
		return err
	}
	if updateCount == 0 {
		return ErrNoRowsUpdate
	}

	return nil
}

func (m *defaultAuthorizationModel) DeleteSoft(ctx context.Context, session sqlx.Session, data *Authorization) error {
	data.DelState = globalkey.DelStateYes
	data.DeleteTime = sql.NullTime{Time: time.Now(), Valid: true}
	if err := m.UpdateWithVersion(ctx, session, data); err != nil {
		return errors.Wrapf(errors.New("delete soft failed "), "AuthorizationModel delete err : %+v", err)
	}
	return nil
}

func (m *defaultAuthorizationModel) FindSum(ctx context.Context, builder squirrel.SelectBuilder, field string) (float64, error) {

	if len(field) == 0 {
		return 0, errors.Wrapf(errors.New("FindSum Least One Field"), "FindSum Least One Field")
	}

	builder = builder.Columns("IFNULL(SUM(" + field + "),0)")

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).ToSql()
	if err != nil {
		return 0, err
	}

	var resp float64
	err = m.QueryRowNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return 0, err
	}
}

func (m *defaultAuthorizationModel) FindCount(ctx context.Context, builder squirrel.SelectBuilder, field string) (int64, error) {

	if len(field) == 0 {
		return 0, errors.Wrapf(errors.New("FindCount Least One Field"), "FindCount Least One Field")
	}

	builder = builder.Columns("COUNT(" + field + ")")

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).ToSql()
	if err != nil {
		return 0, err
	}

	var resp int64
	err = m.QueryRowNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return 0, err
	}
}

func (m *defaultAuthorizationModel) FindAll(ctx context.Context, builder squirrel.SelectBuilder, orderBy string) ([]*Authorization, error) {

	builder = builder.Columns(authorizationRows)

	if orderBy == "" {
		builder = builder.OrderBy("id DESC")
	} else {
		builder = builder.OrderBy(orderBy)
	}

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).ToSql()
	if err != nil {
		return nil, err
	}

	var resp []*Authorization
	err = m.QueryRowsNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) FindPageListByPage(ctx context.Context, builder squirrel.SelectBuilder, page, pageSize int64, orderBy string) ([]*Authorization, error) {

	builder = builder.Columns(authorizationRows)

	if orderBy == "" {
		builder = builder.OrderBy("id DESC")
	} else {
		builder = builder.OrderBy(orderBy)
	}

	if page < 1 {
		page = 1
	}
	offset := (page - 1) * pageSize

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).Offset(uint64(offset)).Limit(uint64(pageSize)).ToSql()
	if err != nil {
		return nil, err
	}

	var resp []*Authorization
	err = m.QueryRowsNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) FindPageListByPageWithTotal(ctx context.Context, builder squirrel.SelectBuilder, page, pageSize int64, orderBy string) ([]*Authorization, int64, error) {

	total, err := m.FindCount(ctx, builder, "id")
	if err != nil {
		return nil, 0, err
	}

	builder = builder.Columns(authorizationRows)

	if orderBy == "" {
		builder = builder.OrderBy("id DESC")
	} else {
		builder = builder.OrderBy(orderBy)
	}

	if page < 1 {
		page = 1
	}
	offset := (page - 1) * pageSize

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).Offset(uint64(offset)).Limit(uint64(pageSize)).ToSql()
	if err != nil {
		return nil, total, err
	}

	var resp []*Authorization
	err = m.QueryRowsNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, total, nil
	default:
		return nil, total, err
	}
}

func (m *defaultAuthorizationModel) FindPageListByIdDESC(ctx context.Context, builder squirrel.SelectBuilder, preMinId, pageSize int64) ([]*Authorization, error) {

	builder = builder.Columns(authorizationRows)

	if preMinId > 0 {
		builder = builder.Where(" id < ? ", preMinId)
	}

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).OrderBy("id DESC").Limit(uint64(pageSize)).ToSql()
	if err != nil {
		return nil, err
	}

	var resp []*Authorization
	err = m.QueryRowsNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) FindPageListByIdASC(ctx context.Context, builder squirrel.SelectBuilder, preMaxId, pageSize int64) ([]*Authorization, error) {

	builder = builder.Columns(authorizationRows)

	if preMaxId > 0 {
		builder = builder.Where(" id > ? ", preMaxId)
	}

	query, values, err := builder.Where("del_state = ?", globalkey.DelStateNo).OrderBy("id ASC").Limit(uint64(pageSize)).ToSql()
	if err != nil {
		return nil, err
	}

	var resp []*Authorization
	err = m.QueryRowsNoCacheCtx(ctx, &resp, query, values...)
	switch err {
	case nil:
		return resp, nil
	default:
		return nil, err
	}
}

func (m *defaultAuthorizationModel) Trans(ctx context.Context, fn func(ctx context.Context, session sqlx.Session) error) error {

	return m.TransactCtx(ctx, func(ctx context.Context, session sqlx.Session) error {
		return fn(ctx, session)
	})

}

func (m *defaultAuthorizationModel) SelectBuilder() squirrel.SelectBuilder {
	return squirrel.Select().From(m.table)
}
func (m *defaultAuthorizationModel) Delete(ctx context.Context, session sqlx.Session, id int64) error {
	data, err := m.FindOne(ctx, id)
	if err != nil {
		return err
	}

	qncAuthorizationIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, id)
	qncAuthorizationOrderIdKey := fmt.Sprintf("%s%v", cacheQncAuthorizationOrderIdPrefix, data.OrderId)
	_, err = m.ExecCtx(ctx, func(ctx context.Context, conn sqlx.SqlConn) (result sql.Result, err error) {
		query := fmt.Sprintf("delete from %s where `id` = ?", m.table)
		if session != nil {
			return session.ExecCtx(ctx, query, id)
		}
		return conn.ExecCtx(ctx, query, id)
	}, qncAuthorizationIdKey, qncAuthorizationOrderIdKey)
	return err
}
func (m *defaultAuthorizationModel) formatPrimary(primary interface{}) string {
	return fmt.Sprintf("%s%v", cacheQncAuthorizationIdPrefix, primary)
}
func (m *defaultAuthorizationModel) queryPrimary(ctx context.Context, conn sqlx.SqlConn, v, primary interface{}) error {
	query := fmt.Sprintf("select %s from %s where `id` = ? and del_state = ? limit 1", authorizationRows, m.table)
	return conn.QueryRowCtx(ctx, v, query, primary, globalkey.DelStateNo)
}

func (m *defaultAuthorizationModel) tableName() string {
	return m.table
}
